@@ -1,4 +1,9 @@
-import cStringIO
+try:
+    # python2
+    from StringIO import StringIO
+except Exception:
+    # python3
+    from io import BytesIO as StringIO
 import datetime
 from psycopg2.extensions import AsIs
 
@@ -854,7 +859,7 @@ def get_metric_data_csv(session, metric_name, start, end, host_id=None,
 
     metric = METRICS.get(metric_name)
     # Instanciate a new string buffer needed by copy_expert()
-    data_buffer = cStringIO.StringIO()
+    data_buffer = StringIO()
     # Get a new psycopg2 cursor from the current sqlalchemy session
     cur = session.connection().connection.cursor()
     # Change working schema to 'monitoring'
@@ -867,6 +872,7 @@ def get_metric_data_csv(session, metric_name, start, end, host_id=None,
     query = cur.mogrify(q_tpl, dict(host_id=host_id, instance_id=instance_id,
                                     start=start, end=end, key=key,
                                     tablename=AsIs(tablename)))
+    query = query.decode("utf-8")
     # Retreive data using copy_expert()
     cur.copy_expert("COPY(" + query + ") TO STDOUT WITH CSV HEADER",
                     data_buffer)
@@ -874,7 +880,7 @@ def get_metric_data_csv(session, metric_name, start, end, host_id=None,
 
     if metric.get('pivot'):
         # Apply pivot rotation
-        data_pivot = cStringIO.StringIO()
+        data_pivot = StringIO()
         pivot_timeserie(
             data_buffer,
             index=metric.get('pivot').get('index'),
@@ -905,7 +911,8 @@ def get_unavailability_csv(session, start, end, host_id, instance_id):
     """
     query = cur.mogrify(sql, dict(instance_id=instance_id,
                                   start=start, end=end))
-    data_buffer = cStringIO.StringIO()
+    query = query.decode("utf-8")
+    data_buffer = StringIO()
     cur.copy_expert("COPY(" + query + ") TO STDOUT", data_buffer)
     data = data_buffer.getvalue()
     data_buffer.close()
